@@ -4,9 +4,9 @@
 from pysudoku_package.config import get_input_files, get_pool_dicts, set_up_tmpdir
 from pysudoku_package.io import txt_writer, file_compiler
 from pysudoku_package.alignment import run_bowtie2, parse_bowtie2_output
-from pysudoku_package.trimming import read_data
+from pysudoku_package.trimming import read_data, detect_barcodes
 from pysudoku_package.generate_count_matrix import  get_count_matrix, get_hash_ids, filter_barcodes, filter_counts
-from pysudoku_package.deconvolution import get_ambiguity, get_unambiguous_locations, coords2genes, transpose_location_summary
+from pysudoku_package.deconvolution import get_ambiguity, get_unambiguous_locations, coords2genes, transpose_location_summary, transpose_barcode_summary
 from pysudoku_package.predict_locations import predict_ambiguous_locations
 import multiprocessing as mp
 from itertools import repeat
@@ -94,7 +94,7 @@ class LibraryExperiment(object):
 
 
 
-    def get_genomic_seq(self):
+    def get_genomic_seq(self, barcode_only=False):
         
         """ 
         Trims all the reads based on the presence of the transposon recognizing
@@ -108,17 +108,31 @@ class LibraryExperiment(object):
         self.input_file_paths, self.input_file_names = get_input_files(self)
 
         set_up_tmpdir()
-
-        pool = mp.Pool(self.cores)
-
-        paths = pool.starmap_async(read_data, zip(self.input_file_paths, repeat(self))).get()
-
-        pool.close()
-        pool.join()
         
-        trimmed_paths = [item for item in paths]
+        # if barcode only mode is run no need to trim sequences for alignment
+        if barcode_only:
+            pool = mp.Pool(self.cores)
+    
+            paths = pool.starmap_async(detect_barcodes, zip(self.input_file_paths, repeat(self))).get()
+    
+            pool.close()
+            pool.join()
+            
+            barcode_paths = [item for item in paths]
+    
+            file_compiler(os.path.join("temp", "alignment_result.csv"), barcode_paths)
 
-        file_compiler(os.path.join("temp", "trimmed_sequences.fastq"), trimmed_paths)
+        else:
+            pool = mp.Pool(self.cores)
+    
+            paths = pool.starmap_async(read_data, zip(self.input_file_paths, repeat(self))).get()
+    
+            pool.close()
+            pool.join()
+            
+            trimmed_paths = [item for item in paths]
+    
+            file_compiler(os.path.join("temp", "trimmed_sequences.fastq"), trimmed_paths)
 
     
     def align_genomic_seq(self):
@@ -136,7 +150,7 @@ class LibraryExperiment(object):
         run_bowtie2(self)
         parse_bowtie2_output(self)
     
-    def write_count_matrix(self):
+    def write_count_matrix(self, barcode_only=False):
         """
         Assembles count matrix from bowtie2 alignment. Filters out spurious 
         barcodes with very little read counts for a given coordinate.
@@ -159,14 +173,17 @@ class LibraryExperiment(object):
 
         count_mat = get_count_matrix(encoded_ids, bowtie_res, self)
         count_mat.to_csv("count_matrix.csv", index=False, float_format="%.0f")
-
-        filtered_count_mat = filter_barcodes(count_mat, self)
-        filtered_count_mat.to_csv("filtered_count_matrix.csv", index=False, float_format="%.0f")
         
-        self.count_mat = filtered_count_mat
+        if not barcode_only:
+            filtered_count_mat = filter_barcodes(count_mat, self)
+            filtered_count_mat.to_csv("filtered_count_matrix.csv", index=False, float_format="%.0f")
+            
+            self.count_mat = filtered_count_mat
+        else:
+            self.count_mat = count_mat
 
         
-    def deconvolve(self):
+    def deconvolve(self, barcode_only=False):
         """
         Deconvolve mutant count matrix and return summary output with 
         genes names.
@@ -196,14 +213,22 @@ class LibraryExperiment(object):
         # if "Barcode" in self.count_mat.columns:
         #     assert np.all(locations["Barcode"].values == self.count_mat["Barcode"].values), \
         #         "Barcodes of locations and data not aligned!"
-        
-        location_summary = coords2genes(self, locations)
-        self.location_summary = location_summary
-        location_summary.to_csv("mutant_location_summary.csv", index=False)
-        
-        transposed_location_summary = transpose_location_summary(self, location_summary)
-        self.transposed_location_summary = transposed_location_summary
-        transposed_location_summary.to_csv("well_location_summary.csv", index=False)
+        if barcode_only:
+            locations.drop(["Reference", "Feature", "Orientation"], axis=1, inplace=True)
+            locations.to_csv("barcode_location_summary.csv", index=False)
+            
+            transposed_barcode_summary = transpose_barcode_summary(self, locations)
+            self.transposed_barcode_summary = transposed_barcode_summary
+            transposed_barcode_summary.to_csv("well_barcode_summary.csv", index=False)
+
+        else:
+            location_summary = coords2genes(self, locations)
+            self.location_summary = location_summary
+            location_summary.to_csv("mutant_location_summary.csv", index=False)
+            
+            transposed_location_summary = transpose_location_summary(self, location_summary)
+            self.transposed_location_summary = transposed_location_summary
+            transposed_location_summary.to_csv("well_location_summary.csv", index=False)
 
 
 # experiment = LibraryExperiment(8,30,10,"gb_ref/UTI89.gb", "bowtie_ref/UTI89", 
